//******************************************************************************
//  LaunchPad Lab4 - Timer Toggle P1.6,
//
//                MSP430G2452
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.6|-->LED
//
//******************************************************************************

#include  <msp430g2452.h>

void main(void)
{
	WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer

	if (CALBC1_1MHZ ==0xFF || CALDCO_1MHZ == 0xFF)
	{
		while(1);            	// If calibration constants erased, trap CPU!!
	}

	BCSCTL1 = CALBC1_1MHZ; 		    // Set range
	DCOCTL = CALDCO_1MHZ;  		    // Set DCO step + modulation
	BCSCTL3 |= LFXT1S_2;                      // LFXT1 = VLO

	P1DIR = 0x40;                             // P1.6 output (green LED)
	P1OUT = 0;                                // LED off

	IFG1 &= ~OFIFG;                           // Clear OSCFault flag
	BCSCTL1 |= DIVA_3;						  // ACLK = VLO/8
	BCSCTL2 |= SELM_3 + DIVM_3 + DIVS_3;      // MCLK = DCO/8, SMCLK = DCO/8

	// Configure TimerA
	TACTL = __________________;          // Source: ACLK, UP mode
	CCR0 = 5100;					//Timer count 5100
	CCR1 = 100;						//Timer count 100
	CCTL0 = CCIE;                  	//CCR0 interrupt enabled
	CCTL1 = CCIE;                  	//CCR1 interrupt enabled

	_BIS_SR(GIE);

	for(;;);
}

// Timer A0 interrupt service routine
#pragma vector=________________
__interrupt void Timer_A0 (void)
{
	P1OUT |= BIT6;                // P1.6 output High
}

// Timer A1 Interrupt Vector (TA0IV) handler
#pragma vector=_______________
__interrupt void Timer_A1(void)
{
	switch( TA0IV )
	{
	case  2: P1OUT &= ~BIT6;                    // P1.6 output Low
           break;
	case 10:
           break;
 }
}
